==> tine20-allinone_2016.11.24.tar.bz2: Felamimail/js/Felamimail-lang-en_AU-debug.js <==
/********************** tine translations of Felamimail**********************/ 
Locale.Gettext.prototype._msgs['./LC_MESSAGES/Felamimail'] = new Locale.Gettext.PO(({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2016-03-17 10:50+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: English (Australia) (http://www.transifex.com/tine20/tine20/language/en_AU/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: en_AU\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "manage email accounts"
: ""

, "Edit and delete email accounts"
: ""

, "Add email accounts"
: ""

, "Create new email accounts"
: ""

, "Reading Confirmation:"
: ""

, "Your message:"
: ""

, "Received on"
: ""

, "Was read by:"
: ""

, "on"
: ""

, "Delete"
: ""

, "Reply"
: ""

, "Reply To All"
: ""

, "Forward"
: ""

, "Save"
: ""

, "Print Message"
: ""

, "Print Preview"
: ""

, "Sieve Filter Rules"
: ""

, "Sieve Filter Rules for {0}"
: ""

, "Vacation Message for {0}"
: ""

, "General"
: ""

, "Advanced"
: ""

, "Only send all X days to the same sender"
: ""

, "Incoming mails will be answered with this text:"
: ""

, "Status"
: ""

, "I am available (vacation message disabled)"
: ""

, "I am not available (vacation message enabled)"
: ""

, "Start Date"
: ""

, "Set vacation start date ..."
: ""

, "End Date"
: ""

, "Set vacation end date ..."
: ""

, "Representative #1"
: ""

, "Choose first Representative ..."
: ""

, "Representative #2"
: ""

, "Choose second Representative ..."
: ""

, "Message Template"
: ""

, "Choose Template ..."
: ""

, "Move up"
: ""

, "Move down"
: ""

, "Enable"
: ""

, "Disable"
: ""

, "ID"
: ""

, "Conditions"
: ""

, "Action"
: ""

, "is greater than"
: ""

, "is less than"
: ""

, "Header \"{0}\" contains \"{1}\""
: ""

, "Header \"{0}\" matches \"{1}\""
: ""

, "From (Email)"
: ""

, "From (Email and Name)"
: ""

, "To (Email)"
: ""

, "To (Email CC)"
: ""

, "Subject"
: ""

, "Size"
: ""

, "Header contains"
: ""

, "Header name"
: ""

, "Header value"
: ""

, "Header regex"
: ""

, "Edit Filter Rule"
: ""

, "Apply filter if"
: ""

, "all conditions match"
: ""

, "any condition matches"
: ""

, "Do this action:"
: ""

, "Move mail to folder"
: ""

, "Redirect mail to address"
: ""

, "Reject mail with this text"
: ""

, "Discard mail"
: ""

, "Keep mail"
: ""

, "Total Messages:"
: ""

, "Unread Messages:"
: ""

, "Name on Server:"
: ""

, "Last update:"
: ""

, "Fetching messages... ({0} done)"
: ""

, "{0} unread message, {0} unread messages"
: [
  ""
 ,""

]
, "Message not available."
: ""

, "From"
: ""

, "Add"
: ""

, "Add contact to addressbook"
: ""

, "Date"
: ""

, "Show or hide header information"
: ""

, "Attachments"
: ""

, "Compose email"
: ""

, "To"
: ""

, "CC"
: ""

, "BCC"
: ""

, "Recipient filter"
: ""

, "All recipients"
: ""

, "\"{0}\" recipients"
: ""

, "Folder, Folders"
: [
  ""
 ,""

]
, "Empty Folder"
: ""

, "Add Folder"
: ""

, "New {0}"
: ""

, "Please enter the name of the new {0}:"
: ""

, "No {0} added"
: ""

, "You have to supply a {0} name!"
: ""

, "Please wait"
: ""

, "Creating {0}..."
: ""

, "Edit Account"
: ""

, "Edit Vacation Message"
: ""

, "Edit Filter Rules"
: ""

, "Mark Folder as read"
: ""

, "Update Folder List"
: ""

, "Message, Messages"
: [
  ""
 ,""

]
, "Subject/From"
: ""

, "From (Name)"
: ""

, "Cc"
: ""

, "Bcc"
: ""

, "Flags"
: ""

, "Received"
: ""

, "Account, Accounts"
: [
  ""
 ,""

]
, "Email Accounts, Email Accounts"
: [
  ""
 ,""

]
, "INBOX"
: ""

, "Drafts"
: ""

, "Sent"
: ""

, "Templates"
: ""

, "Junk"
: ""

, "Trash"
: ""

, "record list, record lists"
: [
  ""
 ,""

]
, "Vacation, Vacations"
: [
  ""
 ,""

]
, "Rule, Rules"
: [
  ""
 ,""

]
, "Flag, Flags"
: [
  ""
 ,""

]
, "Flag list, Flag lists"
: [
  ""
 ,""

]
, "Send"
: ""

, "Search Recipients"
: ""

, "Save As Draft"
: ""

, "Save As Template"
: ""

, "Save Email Note"
: ""

, "Activate this toggle button to save the email text as a note attached to the recipient(s) contact(s)."
: ""

, "Reading Confirmation"
: ""

, "Activate this toggle button to receive a reading confirmation."
: ""

, "Encrypt Email"
: ""

, "Encrypt email using Mailvelope"
: ""

, "Click to search for and add recipients from the Addressbook."
: ""

, "Encrypted Content"
: ""

, "Loading Mail Addresses"
: ""

, "Fwd:"
: ""

, "{0} Message"
: ""

, "Failed"
: ""

, "{0} account setting empty."
: ""

, "Files are still uploading."
: ""

, "On {0}, {1} wrote"
: ""

, "Original message"
: ""

, "Compose email:"
: ""

, "Body"
: ""

, "Empty subject"
: ""

, "Do you really want to send a message with an empty subject?"
: ""

, "Add Note"
: ""

, "Edit Email Note Text:"
: ""

, "No recipients set."
: ""

, "Cannot encrypt message. Public keys for the following recipients are missing: {0}"
: ""

, "Click here to set To/CC/BCC."
: ""

, "To:"
: ""

, "Cc:"
: ""

, "Bcc:"
: ""

, "Remove"
: ""

, "Cancel"
: ""

, "Ok"
: ""

, "Folders of account {0}"
: ""

, "Folders of all accounts"
: ""

, "No Messages found or the cache is empty."
: ""

, "Quota usage"
: ""

, "Compose"
: ""

, "Toggle highlighting"
: ""

, "Mark read/unread"
: ""

, "Add Account"
: ""

, "Id"
: ""

, "Sender"
: ""

, "Answered"
: ""

, "Forwarded"
: ""

, "Tine20"
: ""

, "Recent"
: ""

, "Send Reading Confirmation"
: ""

, "Do you want to send a reading confirmation message?"
: ""

, "{0} %"
: ""

, "Your quota"
: ""

, "{0} available (total: {1})"
: ""

, "To decrypt this message please install {0} with API support enabled"
: ""

, "PGP encrypted Message"
: ""

, "(new message)"
: ""

, "Select recipients for \"{0}\""
: ""

, "None"
: ""

, "Add as \"To\""
: ""

, "Add as \"Cc\""
: ""

, "Add as \"Bcc\""
: ""

, "Remove from recipients"
: ""

, "New Mail"
: ""

, "Email"
: ""

, "Active Vacation Message"
: ""

, "Email account \"{0}\" has an active vacation message."
: ""

, "{0} as default mailer"
: ""

, "New mails"
: ""

, "You got {0} new mail(s) in folder {1} ({2})."
: ""

, "IMAP Credentials for {0}"
: ""

, "Credentials"
: ""

, "IMAP Error"
: ""

, "No connection to IMAP server."
: ""

, "IMAP Credentials Error"
: ""

, "Your email credentials are wrong. Please contact your administrator"
: ""

, "One of your folders was deleted or renamed by another client. Please update the folder list of this account."
: ""

, "SMTP Error"
: ""

, "No connection to SMTP server."
: ""

, "Sieve Error"
: ""

, "No connection to Sieve server."
: ""

, "Save Sieve Script Error"
: ""

, "Could not save script on Sieve server."
: ""

, "Add New Account"
: ""

, "Signature"
: ""

, "Account Name"
: ""

, "User Email"
: ""

, "User Name (From)"
: ""

, "Organization"
: ""

, "Signature position"
: ""

, "Above the quote"
: ""

, "Below the quote"
: ""

, "IMAP"
: ""

, "Host"
: ""

, "Port (Default: 143 / SSL: 993)"
: ""

, "Secure Connection"
: ""

, "TLS"
: ""

, "SSL"
: ""

, "Username"
: ""

, "Password"
: ""

, "SMTP"
: ""

, "Port (Default: 25)"
: ""

, "Authentication"
: ""

, "Login"
: ""

, "Plain"
: ""

, "Username (optional)"
: ""

, "Password (optional)"
: ""

, "Sieve"
: ""

, "Port (Default: 2000)"
: ""

, "Other Settings"
: ""

, "Sent Folder Name"
: ""

, "Trash Folder Name"
: ""

, "Drafts Folder Name"
: ""

, "Templates Folder Name"
: ""

, "Display Format"
: ""

, "HTML"
: ""

, "Plain Text"
: ""

, "Depending on content type (experimental)"
: ""

, "Error: %s"
: ""

, "Could not send message"
: ""

, "Seen"
: ""

, "Deleted"
: ""

, "Draft"
: ""

, "Flagged"
: ""

, "Out of Office reply from %1$s"
: ""

, "All inboxes"
: ""

, "Default Email Account"
: ""

, "The default email account to use when sending mails."
: ""

, "Email Update Interval"
: ""

, "How often should Felamimail check for new Emails (in minutes)."
: ""

, "Use for mailto links"
: ""

, "Use Felamimail in mailto links, otherwise use the default desktop client."
: ""

, "Use for NOTES"
: ""

, "Save Note default Value."
: ""

, "Confirm Delete"
: ""

, "Show confirmation dialog when deleting mails."
: ""

, ".eml file Attachment in forwarded mails"
: ""

, "Attach an .eml file to a forwarded mail. Otherwise all attachments separate"
: ""

, "Vacation Templates Container ID"
: ""

, "Custom Vacation Message"
: ""

, "User is allowed to set custom vacation message for system account"
: ""

, "Cache email body"
: ""

, "Should the email body be cached (recommended for slow IMAP server connections)"
: ""

, "Enabled Features"
: ""

, "Enabled features in Felamimail application."
: ""

, "Tine 2.0 Flag"
: ""

, "Add a Tine 2.0 flag to sent messages"
: ""

, "Filter E-Mail URIs"
: ""

, "Should the email body uris be filtered. Only anchors with URIs are allowed if this is turned on.)"
: ""

, "All inboxes of my email accounts"
: ""

, "All unread mail"
: ""

, "All unread mail of my email accounts"
: ""

, "All highlighted mail"
: ""

, "All highlighted mail of my email accounts"
: ""

, "All drafts"
: ""

, "All mails with the draft flag"
: ""

, "{0} unread message"
: ""

, "Folder"
: ""

, "Message"
: ""

, "Account"
: ""

, "Email Accounts"
: ""

, "record list"
: ""

, "Vacation"
: ""

, "Rule"
: ""

, "Flag"
: ""

, "Flag list"
: ""

}));

==> tine20-allinone_2018.08.9.tar.bz2: Felamimail/js/Felamimail-lang-en_AU-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Felamimail **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: English (Australia) (http://www.transifex.com/tine20/tine20/language/en_AU/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: en_AU\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Message File Location, Message File Locations"
: [
  ""
 ,""

]
, "Message File Locations"
: ""

, "Message ID Hash"
: ""

, "Message ID"
: ""

, "Model"
: ""

, "Record ID"
: ""

, "Record Title"
: ""

, "Type"
: ""

, "Reading Confirmation:"
: ""

, "Your message:"
: ""

, "Received on"
: ""

, "Was read by:"
: ""

, "on"
: ""

, "Delete"
: ""

, "Reply"
: ""

, "Reply To All"
: ""

, "Forward"
: ""

, "Save"
: ""

, "Print Message"
: ""

, "Print Preview"
: ""

, "Total Messages:"
: ""

, "Unread Messages:"
: ""

, "Name on Server:"
: ""

, "Last update:"
: ""

, "Fetching messages... ({0} done)"
: ""

, "{0} unread message, {0} unread messages"
: [
  ""
 ,""

]
, "Mailvelope decryption Error [{0}]"
: ""

, "To decrypt this message please install {0} with API support enabled"
: ""

, "PGP encrypted Message"
: ""

, "Empty Folder"
: ""

, "Add Folder"
: ""

, "New {0}"
: ""

, "Folder, Folders"
: [
  ""
 ,""

]
, "Please enter the name of the new {0}:"
: ""

, "No {0} added"
: ""

, "You have to supply a {0} name!"
: ""

, "Please wait"
: ""

, "Creating {0}..."
: ""

, "Edit Account"
: ""

, "Edit Vacation Message"
: ""

, "Edit Filter Rules"
: ""

, "Notifications"
: ""

, "Mark Folder as read"
: ""

, "Update Folder List"
: ""

, "Recipient filter"
: ""

, "All recipients"
: ""

, "\"{0}\" recipients"
: ""

, "(new message)"
: ""

, "Select recipients for \"{0}\""
: ""

, "No Messages found."
: ""

, "Compose"
: ""

, "Toggle highlighting"
: ""

, "Mark read/unread"
: ""

, "Move"
: ""

, "File Message"
: ""

, "Add Account"
: ""

, "Id"
: ""

, "Attachments"
: ""

, "Flags"
: ""

, "Subject"
: ""

, "From (Email)"
: ""

, "From (Name)"
: ""

, "Sender"
: ""

, "To"
: ""

, "Sent"
: ""

, "Received"
: ""

, "Size"
: ""

, "Answered"
: ""

, "Forwarded"
: ""

, "Tine20"
: ""

, "Recent"
: ""

, "Select Save Location"
: ""

, "Filing Messages"
: ""

, "Error Filing Message"
: ""

, "Could not file message."
: ""

, "Send Reading Confirmation"
: ""

, "Do you want to send a reading confirmation message?"
: ""

, "Compose email"
: ""

, "CC"
: ""

, "BCC"
: ""

, "Mass Mailing"
: ""

, "None"
: ""

, "Add as \"To\""
: ""

, "Add as \"Cc\""
: ""

, "Add as \"Bcc\""
: ""

, "Remove from recipients"
: ""

, "Loading Mail Addresses"
: ""

, "Message, Messages"
: [
  ""
 ,""

]
, "Subject/From"
: ""

, "Cc"
: ""

, "Bcc"
: ""

, "Account, Accounts"
: [
  ""
 ,""

]
, "Email Accounts, Email Accounts"
: [
  ""
 ,""

]
, "INBOX"
: ""

, "Drafts"
: ""

, "Templates"
: ""

, "Junk"
: ""

, "Trash"
: ""

, "record list, record lists"
: [
  ""
 ,""

]
, "Vacation, Vacations"
: [
  ""
 ,""

]
, "Rule, Rules"
: [
  ""
 ,""

]
, "Flag, Flags"
: [
  ""
 ,""

]
, "Flag list, Flag lists"
: [
  ""
 ,""

]
, "New Mail"
: ""

, "Email"
: ""

, "Active Vacation Message"
: ""

, "Email account \"{0}\" has an active vacation message."
: ""

, "Poll URL: {0}"
: ""

, "{0} as default mailer"
: ""

, "New mails"
: ""

, "You got {0} new mail(s) in folder {1} ({2})."
: ""

, "IMAP Credentials for {0}"
: ""

, "Credentials"
: ""

, "IMAP Error"
: ""

, "No connection to IMAP server."
: ""

, "IMAP Credentials Error"
: ""

, "Your email credentials are wrong. Please contact your administrator"
: ""

, "One of your folders was deleted or renamed by another client. Please update the folder list of this account."
: ""

, "SMTP Error"
: ""

, "No connection to SMTP server."
: ""

, "Sieve Error"
: ""

, "No connection to Sieve server."
: ""

, "Save Sieve Script Error"
: ""

, "Could not save script on Sieve server."
: ""

, "Cancel"
: ""

, "Ok"
: ""

, "Folders of account {0}"
: ""

, "Folders of all accounts"
: ""

, "Click here to set To/CC/BCC."
: ""

, "To:"
: ""

, "Cc:"
: ""

, "Bcc:"
: ""

, "Remove"
: ""

, "Send"
: ""

, "Search Recipients"
: ""

, "Save As Draft"
: ""

, "Save As Template"
: ""

, "Save Email Note"
: ""

, "Activate this toggle button to save the email text as a note attached to the recipient(s) contact(s)."
: ""

, "Reading Confirmation"
: ""

, "Activate this toggle button to receive a reading confirmation."
: ""

, "Encrypt Email"
: ""

, "Encrypt email using Mailvelope"
: ""

, "Activate this toggle button to send the mail as separate mail to each recipient."
: ""

, "Click to search for and add recipients from the Addressbook."
: ""

, "Encrypted Content"
: ""

, "Fwd:"
: ""

, "{0} Message"
: ""

, "Failed"
: ""

, "{0} account setting empty."
: ""

, "Files are still uploading."
: ""

, "On {0}, {1} wrote"
: ""

, "Original message"
: ""

, "Compose email:"
: ""

, "From"
: ""

, "Convert to formated text"
: ""

, "Body"
: ""

, "NOTE: This is mail will be sent as a mass mail, i.e. each recipient will get his or her own copy."
: ""

, "Reply-To Email"
: ""

, "Add email address here for reply-to"
: ""

, "Warning"
: ""

, "Some attachments are of type \"systemlinks\" whereas some of the recipients (marked yellow), couldn't be validated to be accounts on this installation. Only recipients with an active account will be able to open those attachments."
: ""

, "Do you really want to send?"
: ""

, "Empty subject"
: ""

, "Do you really want to send a message with an empty subject?"
: ""

, "No recipients set."
: ""

, "Cannot encrypt message. Public keys for the following recipients are missing: {0}"
: ""

, "Edit Filter Rule"
: ""

, "Apply filter if"
: ""

, "all conditions match"
: ""

, "any condition matches"
: ""

, "Do this action:"
: ""

, "Keep a copy"
: ""

, "Move mail to folder"
: ""

, "Redirect mail to address"
: ""

, "Reject mail with this text"
: ""

, "Discard mail"
: ""

, "Keep mail"
: ""

, "Move up"
: ""

, "Move down"
: ""

, "Enable"
: ""

, "Disable"
: ""

, "ID"
: ""

, "Conditions"
: ""

, "Action"
: ""

, "is greater than"
: ""

, "is less than"
: ""

, "Header \"{0}\" contains \"{1}\""
: ""

, "Header \"{0}\" matches \"{1}\""
: ""

, "Notification for {0}"
: ""

, "Notification Email"
: ""

, "From (Email and Name)"
: ""

, "To (Email)"
: ""

, "To (Email CC)"
: ""

, "Header contains"
: ""

, "Header name"
: ""

, "Header value"
: ""

, "Header regex"
: ""

, "Sieve Filter Rules"
: ""

, "Sieve Filter Rules for {0}"
: ""

, "Vacation Message for {0}"
: ""

, "General"
: ""

, "Advanced"
: ""

, "Only send all X days to the same sender"
: ""

, "Incoming mails will be answered with this text:"
: ""

, "Status"
: ""

, "I am available (vacation message disabled)"
: ""

, "I am not available (vacation message enabled)"
: ""

, "Start Date"
: ""

, "Set vacation start date ..."
: ""

, "End Date"
: ""

, "Set vacation end date ..."
: ""

, "Representative #1"
: ""

, "Choose first Representative ..."
: ""

, "Representative #2"
: ""

, "Choose second Representative ..."
: ""

, "Message Template"
: ""

, "Choose Template ..."
: ""

, "Add New Account"
: ""

, "Signature"
: ""

, "Account Name"
: ""

, "User Email"
: ""

, "User Name (From)"
: ""

, "Organization"
: ""

, "Signature position"
: ""

, "Above the quote"
: ""

, "Below the quote"
: ""

, "IMAP"
: ""

, "Host"
: ""

, "Port (Default: 143 / SSL: 993)"
: ""

, "Secure Connection"
: ""

, "TLS"
: ""

, "SSL"
: ""

, "Username"
: ""

, "Password"
: ""

, "SMTP"
: ""

, "Port (Default: 25)"
: ""

, "Authentication"
: ""

, "Login"
: ""

, "Plain"
: ""

, "Username (optional)"
: ""

, "Password (optional)"
: ""

, "Sieve"
: ""

, "Port (Default: 2000)"
: ""

, "Other Settings"
: ""

, "Sent Folder Name"
: ""

, "Trash Folder Name"
: ""

, "Drafts Folder Name"
: ""

, "Templates Folder Name"
: ""

, "Display Format"
: ""

, "HTML"
: ""

, "Plain Text"
: ""

, "Depending on content type (experimental)"
: ""

, "Compose Format"
: ""

, "Preserve Format"
: ""

, "No"
: ""

, "Yes"
: ""

, "Open in Felamimail"
: ""

, "Message not available."
: ""

, "Add"
: ""

, "Add contact to addressbook"
: ""

, "Date"
: ""

, "Show or hide header information"
: ""

, "Download"
: ""

, "Attachment"
: ""

, "Filemanager (Download link)"
: ""

, "Filemanager (Download link, password)"
: ""

, "Filemanager (Systemlink)"
: ""

, "Attachment Type"
: ""

, "Click icon to change"
: ""

, "name"
: ""

, "size"
: ""

, "type"
: ""

, "Failure"
: ""

, "This file is already attached to this record."
: ""

, "All inboxes"
: ""

, "Default Email Account"
: ""

, "The default email account to use when sending mails."
: ""

, "Email Update Interval"
: ""

, "How often should Felamimail check for new Emails (in minutes)."
: ""

, "Use for mailto links"
: ""

, "Use Felamimail in mailto links, otherwise use the default desktop client."
: ""

, "Use for NOTES"
: ""

, "Save Note default Value."
: ""

, "Confirm Delete"
: ""

, "Show confirmation dialog when deleting mails."
: ""

, ".eml file Attachment in forwarded mails"
: ""

, "Attach an .eml file to a forwarded mail. Otherwise all attachments separate"
: ""

, "Vacation Templates Node ID"
: ""

, "Email Notification Templates Node ID"
: ""

, "Custom Vacation Message"
: ""

, "User is allowed to set custom vacation message for system account"
: ""

, "Cache email body"
: ""

, "Should the email body be cached (recommended for slow IMAP server connections)"
: ""

, "Delete Archived Mail"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Felamimail Application."
: ""

, "Tine 2.0 Flag"
: ""

, "Add a Tine 2.0 flag to sent messages"
: ""

, "Show Reply-To"
: ""

, "Show Reply-To field in message compose dialog"
: ""

, "Filter E-Mail URIs"
: ""

, "Should the email body uris be filtered. Only anchors with URIs are allowed if this is turned on"
: ""

, "System Account Folder Defaults"
: ""

, "Paths of the special folders (like Sent, Trash, ...)"
: ""

, "Allow self signed TLS cert for IMAP connection"
: ""

, "Sieve Redirect Only Internal"
: ""

, "Allow only sieve redirect rules to internal (primary/secondary) email addresses"
: ""

, "Sieve Notification Bounces Reporting Email"
: ""

, "manage email accounts"
: ""

, "Edit and delete email accounts"
: ""

, "Add email accounts"
: ""

, "Create new email accounts"
: ""

, "Out of Office reply from %1$s"
: ""

, "You have new mail from "
: ""

, "Seen"
: ""

, "Deleted"
: ""

, "Draft"
: ""

, "Flagged"
: ""

, "Bad recipient address syntax"
: ""

, "Recipient address rejected"
: ""

, "Invalid address format"
: ""

, "Error: %s"
: ""

, "Could not send message"
: ""

, "My Mail Download Links"
: ""

, "All inboxes of my email accounts"
: ""

, "All unread mail"
: ""

, "All unread mail of my email accounts"
: ""

, "All highlighted mail"
: ""

, "All highlighted mail of my email accounts"
: ""

, "All drafts"
: ""

, "All mails with the draft flag"
: ""

, "Message File Location"
: ""

, "{0} unread message"
: ""

, "Folder"
: ""

, "Message"
: ""

, "Account"
: ""

, "Email Accounts"
: ""

, "record list"
: ""

, "Vacation"
: ""

, "Rule"
: ""

, "Flag"
: ""

, "Flag list"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
